import { defineComponent, $prefix, setup, $props } from '@opentinyvue/vue-common';
import { renderless, api } from '@opentinyvue/vue-renderless/popover/vue';
import { iconClose } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
var classes = {
  "title": "text-color-icon-primary font-bold text-xs",
  "popper": "sm:leading-5 sm:absolute sm:px-4 sm:py-3 sm:z-[2000] sm:text-justify sm:text-xs break-all sm:max-w-[theme(spacing.96)] sm:shadow-md sm:bg-color-bg-1 sm:rounded sm:[&[x-placement^=top]]:mb-2.5 sm:[&[x-placement^=bottom]]:mt-2.5 sm:[&[x-placement^=right]]:ml-2.5 sm:[&[x-placement^=left]]:mr-2.5",
  "arrow": 'absolute ml-0.5 border-b-color-bg-1 border-l-color-bg-1 rounded-bl-sm block w-0 h-0 border-4 border-transparent border-solid after:absolute after:block after:border-transparent after:border-solid after:content-[""]',
  "placement-top": "-bottom-1 left-1/2 -rotate-45",
  "placement-bottom": "-top-1 left-1/2 rotate-[135deg]",
  "placement-right": "-left-1.5 top-1/2 rotate-45",
  "placement-left": "top-1/2 -right-1 rotate-[225deg]"
};
var __vue2_script = defineComponent({
  inheritAttrs: false,
  name: $prefix + "Popover",
  components: {
    IconClose: iconClose()
  },
  emits: ["update:modelValue", "hide", "show", "after-enter", "after-leave", "created"],
  props: _extends({}, $props, {
    appendToBody: {
      type: Boolean,
      default: true
    },
    arrowOffset: {
      type: Number,
      default: 0
    },
    boundariesPadding: {
      type: Number,
      default: 5
    },
    closeDelay: {
      type: Number,
      default: 200
    },
    content: String,
    disabled: Boolean,
    modelValue: Boolean,
    offset: {
      default: 0
    },
    openDelay: {
      type: Number,
      default: 0
    },
    placement: {
      type: String,
      default: "bottom"
    },
    popper: {},
    popperClass: String,
    popperOptions: {
      type: Object,
      default: function _default() {
        return {
          gpuAcceleration: false
        };
      }
    },
    reference: {},
    tabindex: {
      type: Number,
      default: 0
    },
    title: String,
    transformOrigin: {
      type: [Boolean, String],
      default: true
    },
    transition: {
      type: String,
      default: "fade-in-linear"
    },
    trigger: {
      type: String,
      default: "click",
      validator: function validator(value) {
        return ~["click", "focus", "hover", "manual"].indexOf(value);
      }
    },
    visibleArrow: {
      default: true
    },
    genArrowByHtml: {
      type: Boolean,
      default: function _default2() {
        return true;
      }
    },
    width: {}
  }),
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api,
      classes
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("span", {
    ref: "root",
    class: _vm.$attrs.class
  }, [_c("transition", {
    attrs: {
      "name": _vm.transition
    },
    on: {
      "after-enter": _vm.handleAfterEnter,
      "after-leave": _vm.handleAfterLeave
    }
  }, [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: !_vm.disabled && _vm.state.showPopper,
      expression: "!disabled && state.showPopper"
    }],
    ref: "popper",
    class: [_vm.m(_vm.gcls("popper"), _vm.popperClass)],
    style: {
      width: _vm.width + "px"
    },
    attrs: {
      "data-tag": "tiny-popover tiny-popper",
      "role": "tooltip",
      "id": _vm.state.tooltipId,
      "aria-hidden": _vm.disabled || !_vm.state.showPopper ? "true" : "false"
    }
  }, [_c("div", {
    staticClass: "hidden sm:block leading-5.5",
    attrs: {
      "data-tag": "tiny-popover-arrow"
    }
  }, [_vm.slots.header ? _vm._t("header") : _vm.title ? _c("div", {
    class: [_vm.gcls("title")],
    domProps: {
      "textContent": _vm._s(_vm.title)
    }
  }) : _vm._e(), _vm._t("default", function() {
    return [_vm._v(_vm._s(_vm.content))];
  }), _vm._t("footer"), _vm.visibleArrow ? _c("div", {
    class: [_vm.gcls("arrow"), _vm.gcls("placement-" + _vm.state.xPlacement.split("-")[0])],
    attrs: {
      "data-tag": "tiny-popover-visible",
      "x-arrow": ""
    }
  }) : _vm._e()], 2), _c("div", {
    class: ["sm:hidden block fixed left-0 right-0 top-0 bottom-0 text-sm text-color-text-primary transition-top ease-out duration-300", "before:content-[''] before:fixed before:left-0 before:right-0 before:top-0 before:bottom-0 before:w-full before:h-full before:bg-color-bg-7"],
    attrs: {
      "data-tag": "tiny-popover-body"
    }
  }, [_c("div", {
    class: ["absolute bottom-0 top-auto left-1/2 -translate-x-1/2 w-full max-h-full p-3 pointer-events-auto"]
  }, [_c("div", {
    staticClass: "flex flex-col w-full h-full rounded-lg overflow-hidden shadow-xl bg-color-bg-1"
  }, [_c("div", {
    staticClass: "flex items-center leading-6 text-sm px-6 pt-5",
    attrs: {
      "data-tag": "tiny-popover-header"
    }
  }, [_c("span", {
    staticClass: "flex-auto text-base truncate font-semibold"
  }, [_vm._v(_vm._s(_vm.title || _vm.t("ui.alert.title")))]), _c("icon-close", {
    on: {
      "click": function click($event) {
        _vm.state.showPopper = false;
      }
    }
  })], 1), _c("div", {
    staticClass: "flex flex-auto leading-5 overflow-auto mx-6 mt-4 mb-5",
    attrs: {
      "data-tag": "tiny-popover-content"
    }
  }, [_vm._t("default", function() {
    return [_vm._v(" " + _vm._s(_vm.content))];
  })], 2), _vm.slots.footer ? _c("div", {
    staticClass: "w-full py-2.5 px-6 border-t-0.5 border-color-border-separator text-center",
    attrs: {
      "data-tag": "tiny-popover-footer"
    }
  }, [_vm._t("footer")], 2) : _vm._e()])])])])]), _c("span", {
    ref: "wrapper",
    attrs: {
      "data-tag": "tiny-popover-reference"
    }
  }, [_vm._t("reference")], 2)], 1);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };
